# Change Log

## Version 0.0.3 (2023-10-04)

### Changes

- Python 3.8 - 3.11 support.
- Added None and filehandles as disposable objects.

## Version 0.0.2 (2022-02-11)

### Changes

- create_temp_dir and create_temp_file will ensure the full directory path exists.

# Change Log

## Version 0.0.1 (2022-02-09)

### Changes

- Initial release.
